@@ -491,9 +491,15 @@ void        g_vfs_backend_set_mount_spec                 (GVfsBackend        *ba
 void        g_vfs_backend_register_mount                 (GVfsBackend        *backend,
                                                           GAsyncReadyCallback callback,
 							  gpointer            user_data);
+gboolean    g_vfs_backend_register_mount_finish          (GVfsBackend        *backend,
+                                                          GAsyncResult       *res,
+                                                          GError            **error);
 void        g_vfs_backend_unregister_mount               (GVfsBackend        *backend,
                                                           GAsyncReadyCallback callback,
 							  gpointer            user_data);
+gboolean    g_vfs_backend_unregister_mount_finish        (GVfsBackend        *backend,
+                                                          GAsyncResult       *res,
+                                                          GError            **error);
 const char *g_vfs_backend_get_backend_type               (GVfsBackend        *backend);
 const char *g_vfs_backend_get_display_name               (GVfsBackend        *backend);
 const char *g_vfs_backend_get_stable_name                (GVfsBackend        *backend);
@@ -511,11 +517,13 @@ void        g_vfs_backend_add_auto_info                  (GVfsBackend
 							  GFileInfo             *info,
 							  const char            *uri);
 
-void        g_vfs_backend_set_block_requests             (GVfsBackend           *backend);
+void        g_vfs_backend_set_block_requests             (GVfsBackend           *backend,
+                                                          gboolean               value);
 gboolean    g_vfs_backend_get_block_requests             (GVfsBackend           *backend);
 
 gboolean    g_vfs_backend_unmount_with_operation_finish (GVfsBackend  *backend,
-                                                         GAsyncResult *res);
+                                                         GAsyncResult *res,
+                                                         GError      **error);
 
 void        g_vfs_backend_unmount_with_operation (GVfsBackend        *backend,
                                                   GMountSource       *mount_source,
