@@ -760,7 +760,14 @@ should_include_volume_check_mount_points (GVfsUDisks2VolumeMonitor *monitor,
       mount_entry = g_unix_mount_at (mount_point, NULL);
       if (mount_entry != NULL)
         {
-          if (should_include_mount (monitor, mount_entry))
+          const gchar *root = NULL;
+
+#ifdef HAVE_G_UNIX_MOUNT_GET_ROOT_PATH
+          root = g_unix_mount_get_root_path (mount_entry);
+#endif
+
+          if ((root == NULL || g_strcmp0 (root, "/") == 0) &&
+              should_include_mount (monitor, mount_entry))
             {
               g_unix_mount_free (mount_entry);
               ret = TRUE;
@@ -1706,7 +1713,15 @@ update_mounts (GVfsUDisks2VolumeMonitor  *monitor,
   for (l = added; l != NULL; l = l->next)
     {
       GUnixMountEntry *mount_entry = l->data;
-      volume = find_volume_for_device (monitor, g_unix_mount_get_device_path (mount_entry));
+      const gchar *root = NULL;
+
+#ifdef HAVE_G_UNIX_MOUNT_GET_ROOT_PATH
+      root = g_unix_mount_get_root_path (mount_entry);
+#endif
+
+      volume = NULL;
+      if (root == NULL || g_strcmp0 (root, "/") == 0)
+        volume = find_volume_for_device (monitor, g_unix_mount_get_device_path (mount_entry));
       if (volume == NULL)
         volume = find_fstab_volume_for_mount_entry (monitor, mount_entry);
       mount = gvfs_udisks2_mount_new (monitor, mount_entry, volume); /* adopts mount_entry */
@@ -1738,7 +1753,15 @@ update_mounts (GVfsUDisks2VolumeMonitor  *monitor,
         }
       if (gvfs_udisks2_mount_get_volume (mount) == NULL)
         {
-          volume = find_volume_for_device (monitor, g_unix_mount_get_device_path (mount_entry));
+          const gchar *root = NULL;
+
+#ifdef HAVE_G_UNIX_MOUNT_GET_ROOT_PATH
+          root = g_unix_mount_get_root_path (mount_entry);
+#endif
+
+          volume = NULL;
+          if (root == NULL || g_strcmp0 (root, "/") == 0)
+            volume = find_volume_for_device (monitor, g_unix_mount_get_device_path (mount_entry));
           if (volume == NULL)
             volume = find_fstab_volume_for_mount_entry (monitor, mount_entry);
           if (volume != NULL)
